@@ -600,15 +600,9 @@ static int const HalfOrderWord[12] = {
 
 /* Cancel a GetReq operation, before doing _XSend or Data */
 
-#if (defined(__STDC__) && !defined(UNIXCPP)) || defined(ANSICPP)
 #define UnGetReq(name)\
     dpy->bufptr -= SIZEOF(x##name##Req);\
     dpy->request--
-#else
-#define UnGetReq(name)\
-    dpy->bufptr -= SIZEOF(x/**/name/**/Req);\
-    dpy->request--
-#endif
 
 static void
 SendXYImage(
@@ -746,8 +740,7 @@ SendXYImage(
 		    bytes_per_src, bytes_per_line,
 		    bytes_per_dest, req->height, half_order);
 
-    if (extra)
-	Xfree(extra);
+    Xfree(extra);
 
     if (buf == dpy->bufptr)
 	dpy->bufptr += length;
@@ -799,8 +792,7 @@ SendZImage(
 	((req_xoffset == 0) ||
 	 ((req_yoffset + req->height) < (unsigned)image->height))) {
 	Data(dpy, (char *)src, length);
-	if (shifted_src)
-	    Xfree((char *)shifted_src);
+	Xfree(shifted_src);
 	return;
     }
 
@@ -810,7 +802,7 @@ SendZImage(
     else
 	if ((dest = (unsigned char *)
 	     _XAllocScratch(dpy, length)) == NULL) {
-	    if (shifted_src) Xfree((char *) shifted_src);
+	    Xfree(shifted_src);
 	    UnGetReq(PutImage);
 	    return;
 	}
@@ -837,8 +829,7 @@ SendZImage(
     else
 	_XSend(dpy, (char *)dest, length);
 
-    if (shifted_src)
-        Xfree((char *)shifted_src);
+    Xfree(shifted_src);
 }
 
 static void
