@@ -40,6 +40,7 @@
 #include <sys/stat.h>
 #include <stdio.h>
 #include <ctype.h>
+#include <limits.h>
 #define XK_LATIN1
 #include <X11/keysymdef.h>
 #include "Cv.h"
@@ -208,7 +209,7 @@ _XcmsParseColorString(
      * While copying color_string to string_lowered, convert to lowercase
      */
     if ((len = strlen(color_string)) >= sizeof(string_buf)) {
-	string_lowered = (char *) Xmalloc(len+1);
+	string_lowered = Xmalloc(len+1);
     } else {
 	string_lowered = string_buf;
     }
@@ -313,7 +314,7 @@ field2(
 
     /* Find Field 1 */
     while (!isgraph(*pBuf)) {
-	if ((*pBuf != '\n') || (*pBuf != '\0')) {
+	if ((*pBuf == '\n') || (*pBuf == '\0')) {
 	    return(XcmsFailure);
 	}
 	if (isspace(*pBuf) || (*pBuf == delim)) {
@@ -417,7 +418,7 @@ _XcmsLookupColorName(
 
 Retry:
     if ((len = strlen(tmpName)) > 63) {
-	name_lowered = (char *) Xmalloc(len+1);
+	name_lowered = Xmalloc(len+1);
     } else {
 	name_lowered = name_lowered_64;
     }
@@ -542,7 +543,10 @@ stringSectionSize(
     char *pBuf;
     char *f1;
     char *f2;
-    int i;
+    size_t i;
+
+    unsigned int numEntries = 0;
+    unsigned int sectionSize = 0;
 
     *pNumEntries = 0;
     *pSectionSize = 0;
@@ -576,26 +580,37 @@ stringSectionSize(
 	    return(XcmsFailure);
 	}
 
-	(*pNumEntries)++;
+	numEntries++;
+	if (numEntries >= INT_MAX)
+	    return(XcmsFailure);
 
-	(*pSectionSize) += (i = strlen(f1)) + 1;
+	i = strlen(f1);
+	if (i >= INT_MAX - sectionSize)
+	    return(XcmsFailure);
+	sectionSize += i + 1;
 	for (; i; i--, f1++) {
 	    /* REMOVE SPACES FROM COUNT */
 	    if (isspace(*f1)) {
-		(*pSectionSize)--;
+		sectionSize--;
 	    }
 	}
 
-	(*pSectionSize) += (i = strlen(f2)) + 1;
+	i = strlen(f2);
+	if (i >= INT_MAX - sectionSize)
+	    return(XcmsFailure);
+	sectionSize += i + 1;
 	for (; i; i--, f2++) {
 	    /* REMOVE SPACES FROM COUNT */
 	    if (isspace(*f2)) {
-		(*pSectionSize)--;
+		sectionSize--;
 	    }
 	}
 
     }
 
+    *pNumEntries = (int) numEntries;
+    *pSectionSize = (int) sectionSize;
+
     return(XcmsSuccess);
 }
 
@@ -745,8 +760,8 @@ LoadColornameDB(void)
     }
     rewind(stream);
 
-    strings = (char *) Xmalloc(size);
-    pairs = (XcmsPair *)Xcalloc(nEntries, sizeof(XcmsPair));
+    strings = Xmalloc(size);
+    pairs = Xcalloc(nEntries, sizeof(XcmsPair));
 
     ReadColornameDB(stream, pairs, strings);
     (void) fclose(stream);
