@@ -1,4 +1,3 @@
-/* $Xorg: lcWrap.c,v 1.6 2001/02/09 02:03:39 xorgcvs Exp $ */
 /*
 
 Copyright 1991, 1998  The Open Group
@@ -53,7 +52,6 @@ from The Open Group.
  *
  *		 Katsuhisa Yano		TOSHIBA Corp.
  */
-/* $XFree86: xc/lib/X11/lcWrap.c,v 3.15 2003/04/13 19:22:22 dawes Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -79,24 +77,23 @@ XSetLocaleModifiers(
 {
     XLCd lcd = _XlcCurrentLC();
     char *user_mods;
+    char *mapped_mods;
 
     if (!lcd)
 	return (char *) NULL;
     if (!modifiers)
 	return lcd->core->modifiers;
     user_mods = getenv("XMODIFIERS");
-    modifiers = (*lcd->methods->map_modifiers) (lcd,
-						user_mods, (char *)modifiers);
-    if (modifiers) {
-	if (lcd->core->modifiers)
-	    Xfree(lcd->core->modifiers);
-	lcd->core->modifiers = (char *)modifiers;
+    mapped_mods = (*lcd->methods->map_modifiers) (lcd, user_mods, modifiers);
+    if (mapped_mods) {
+	Xfree(lcd->core->modifiers);
+	lcd->core->modifiers = mapped_mods;
     }
-    return (char *)modifiers;
+    return mapped_mods;
 }
 
 Bool
-XSupportsLocale()
+XSupportsLocale(void)
 {
     return _XlcCurrentLC() != (XLCd)NULL;
 }
@@ -220,7 +217,7 @@ _XlcAddLoader(
 
     _XlcRemoveLoader(proc);		/* remove old loader, if exist */
 
-    loader = (XlcLoaderList) Xmalloc(sizeof(XlcLoaderListRec));
+    loader = Xmalloc(sizeof(XlcLoaderListRec));
     if (loader == NULL)
 	return False;
 
@@ -295,7 +292,7 @@ _XOpenLC(
     for (loader = loader_list; loader; loader = loader->next) {
 	lcd = (*loader->proc)(name);
 	if (lcd) {
-	    cur = (XLCdList) Xmalloc (sizeof(XLCdListRec));
+	    cur = Xmalloc (sizeof(XLCdListRec));
 	    if (cur) {
 		cur->lcd = lcd;
 		cur->ref_count = 1;
@@ -349,7 +346,7 @@ _XCloseLC(
  */
 
 XLCd
-_XlcCurrentLC()
+_XlcCurrentLC(void)
 {
     XLCd lcd;
     static XLCd last_lcd = NULL;
@@ -488,7 +485,7 @@ XwcFreeStringList(
 }
 
 const char *
-XDefaultString()
+XDefaultString(void)
 {
     XLCd lcd = _XlcCurrentLC();
 
@@ -567,7 +564,7 @@ _XlcVaToArgList(
 {
     XlcArgList args;
 
-    *args_ret = args = (XlcArgList) Xmalloc(sizeof(XlcArg) * count);
+    *args_ret = args = Xmalloc(sizeof(XlcArg) * count);
     if (args == (XlcArgList) NULL)
 	return;
 
